@@ -24,8 +24,8 @@ from ..exceptions import (
     FleetInstanceLimitError,
     FleetConfigurationError,
 )
-from .client import AsyncFleet, AsyncEnv
-from ..models import InstanceResponse, Environment, AccountResponse
+from .client import AsyncFleet, AsyncEnv, AsyncSession
+from ..models import InstanceResponse, Environment, AccountResponse, Run
 from ..instance.models import Resource, ResetResponse
 
 # Import async verifiers
@@ -44,7 +44,7 @@ from ..types import VerifierFunction
 from .. import env
 from . import global_client as _async_global_client
 
-__version__ = "0.1.0"
+__version__ = "0.2.82"
 
 __all__ = [
     # Core classes
@@ -54,6 +54,7 @@ __all__ = [
     "InstanceResponse",
     "Resource",
     "ResetResponse",
+    "Run",
     # Task models
     "Task",
     "VerifierFunction",
@@ -90,6 +91,7 @@ __all__ = [
     "import_tasks",
     "account",
     "get_task",
+    "list_runs",
     # Version
     "__version__",
 ]
@@ -112,8 +114,11 @@ async def environment(env_key: str) -> Environment:
 
 async def make(
     env_key: str,
+    data_key: Optional[str] = None,
     region: Optional[str] = None,
     env_variables: Optional[Dict[str, Any]] = None,
+    image_type: Optional[str] = None,
+    ttl_seconds: Optional[int] = None,
 ) -> AsyncEnv:
     """Create a new environment instance.
 
@@ -121,7 +126,14 @@ async def make(
         env = await fleet.make("fira")
         env_with_vars = await fleet.make("fira", env_variables={"LOGGED_IN_NAME": "Alice"})
     """
-    return await _async_global_client.get_client().make(env_key, region, env_variables)
+    return await _async_global_client.get_client().make(
+        env_key,
+        data_key=data_key,
+        region=region,
+        env_variables=env_variables,
+        image_type=image_type,
+        ttl_seconds=ttl_seconds,
+    )
 
 
 async def make_for_task(task: Task) -> AsyncEnv:
@@ -245,6 +257,28 @@ async def get_task(task_key: str, version_id: Optional[str] = None):
     )
 
 
+async def list_runs(
+    profile_id: Optional[str] = None, status: Optional[str] = "active"
+) -> List[Run]:
+    """List all runs (groups of instances by run_id) with aggregated statistics.
+
+    Args:
+        profile_id: Optional profile ID to filter runs by (use "self" for your own profile)
+        status: Filter by run status - "active" (default), "inactive", or "all"
+
+    Returns:
+        List[Run] containing run information with instance counts and timestamps
+
+    Example:
+        runs = await fleet.list_runs()
+        my_runs = await fleet.list_runs(profile_id="self")
+        all_runs = await fleet.list_runs(status="all")
+    """
+    return await _async_global_client.get_client().list_runs(
+        profile_id=profile_id, status=status
+    )
+
+
 def configure(
     api_key: Optional[str] = None,
     base_url: Optional[str] = None,
